@@ -90,6 +90,14 @@ atoms = [
             Constant([23.173260452512931])),
         (lambda x: norm(x,"nuc"), (1, 1), [ [[3,4,5],[6,7,8]] ],
             Constant([14.618376738088918])),
+        (lambda x: mixed_norm(x,1,1), (1, 1), [ [[1,2],[3,4],[5,6]] ],
+            Constant([21])),
+        (lambda x: mixed_norm(x,1,1), (1, 1), [ [[1,2,3],[4,5,6]] ],
+            Constant([21])),
+        (lambda x: mixed_norm(x,2,1), (1, 1), [ [[3,3],[4,4]] ],
+            Constant([10])),
+        (lambda x: mixed_norm(x,1,'inf'), (1, 1), [ [[1,4],[5,6]] ],
+            Constant([10])),
         (pos, (1, 1), [8], Constant([8])),
         (pos, (2, 1), [ [-3,2] ], Constant([0,2])),
         (neg, (2, 1), [ [-3,3] ], Constant([3,0])),
